@@ -1,5 +1,5 @@
 package Minion::Backend::MongoDB;
-$Minion::Backend::MongoDB::VERSION = '1.11';
+$Minion::Backend::MongoDB::VERSION = '1.12';
 # ABSTRACT: MongoDB backend for Minion
 
 use 5.016;    # Minion requires this so we require this.
@@ -639,10 +639,6 @@ sub _await {
     $cursor->has_next;
 }
 
-sub _dtkey {
-    return substr( $_[0]->datetime, 0, -6 );
-}
-
 sub _enqueue {
     my ( $self, $task, $args, $options ) = @_;
     @{ $options->{parents} } = map $self->_oid($_), @{ $options->{parents} }
@@ -972,7 +968,7 @@ Minion::Backend::MongoDB - MongoDB backend for Minion
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
